Index: chrome/browser/ui/views/page_info/page_info_popup_view.h |
diff --git a/chrome/browser/ui/views/page_info/website_settings_popup_view.h b/chrome/browser/ui/views/page_info/page_info_popup_view.h |
similarity index 73% |
rename from chrome/browser/ui/views/page_info/website_settings_popup_view.h |
rename to chrome/browser/ui/views/page_info/page_info_popup_view.h |
index 557dc0c705a32636a1f35263014ba12dd379bbbe..c8843627be5827c6c3d7f830ad43e9ad035768e4 100644 |
--- a/chrome/browser/ui/views/page_info/website_settings_popup_view.h |
+++ b/chrome/browser/ui/views/page_info/page_info_popup_view.h |
@@ -2,15 +2,15 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef CHROME_BROWSER_UI_VIEWS_PAGE_INFO_WEBSITE_SETTINGS_POPUP_VIEW_H_ |
-#define CHROME_BROWSER_UI_VIEWS_PAGE_INFO_WEBSITE_SETTINGS_POPUP_VIEW_H_ |
+#ifndef CHROME_BROWSER_UI_VIEWS_PAGE_INFO_PAGE_INFO_POPUP_VIEW_H_ |
+#define CHROME_BROWSER_UI_VIEWS_PAGE_INFO_PAGE_INFO_POPUP_VIEW_H_ |
#include <memory> |
#include "base/compiler_specific.h" |
#include "base/macros.h" |
#include "base/memory/weak_ptr.h" |
-#include "chrome/browser/ui/page_info/website_settings_ui.h" |
+#include "chrome/browser/ui/page_info/page_info_ui.h" |
#include "chrome/browser/ui/views/page_info/chosen_object_row_observer.h" |
#include "chrome/browser/ui/views/page_info/permission_selector_row.h" |
#include "chrome/browser/ui/views/page_info/permission_selector_row_observer.h" |
@@ -38,7 +38,7 @@ struct SecurityInfo; |
} // namespace security_state |
namespace test { |
-class WebsiteSettingsPopupViewTestApi; |
+class PageInfoPopupViewTestApi; |
} |
namespace views { |
@@ -53,23 +53,23 @@ enum : int { |
kPermissionIconColumnWidth = 16, |
}; |
-// The views implementation of the website settings UI. |
-class WebsiteSettingsPopupView : public content::WebContentsObserver, |
- public PermissionSelectorRowObserver, |
- public ChosenObjectRowObserver, |
- public views::BubbleDialogDelegateView, |
- public views::ButtonListener, |
- public views::LinkListener, |
- public views::StyledLabelListener, |
- public WebsiteSettingsUI { |
+// The views implementation of the page info UI. |
+class PageInfoPopupView : public content::WebContentsObserver, |
+ public PermissionSelectorRowObserver, |
+ public ChosenObjectRowObserver, |
+ public views::BubbleDialogDelegateView, |
+ public views::ButtonListener, |
+ public views::LinkListener, |
+ public views::StyledLabelListener, |
+ public PageInfoUI { |
public: |
- ~WebsiteSettingsPopupView() override; |
+ ~PageInfoPopupView() override; |
// Type of the popup being displayed. |
enum PopupType { |
POPUP_NONE, |
// Usual page info bubble for websites. |
- POPUP_WEBSITE_SETTINGS, |
+ POPUP_PAGE_INFO, |
// Custom bubble for internal pages like chrome:// and chrome-extensions://. |
POPUP_INTERNAL_PAGE |
}; |
@@ -86,14 +86,14 @@ class WebsiteSettingsPopupView : public content::WebContentsObserver, |
static PopupType GetShownPopupType(); |
private: |
- friend class test::WebsiteSettingsPopupViewTestApi; |
+ friend class test::PageInfoPopupViewTestApi; |
- WebsiteSettingsPopupView(views::View* anchor_view, |
- gfx::NativeView parent_window, |
- Profile* profile, |
- content::WebContents* web_contents, |
- const GURL& url, |
- const security_state::SecurityInfo& security_info); |
+ PageInfoPopupView(views::View* anchor_view, |
+ gfx::NativeView parent_window, |
+ Profile* profile, |
+ content::WebContents* web_contents, |
+ const GURL& url, |
+ const security_state::SecurityInfo& security_info); |
// WebContentsObserver implementation. |
void RenderFrameDeleted(content::RenderFrameHost* render_frame_host) override; |
@@ -101,11 +101,10 @@ class WebsiteSettingsPopupView : public content::WebContentsObserver, |
// PermissionSelectorRowObserver implementation. |
void OnPermissionChanged( |
- const WebsiteSettingsUI::PermissionInfo& permission) override; |
+ const PageInfoUI::PermissionInfo& permission) override; |
// ChosenObjectRowObserver implementation. |
- void OnChosenObjectDeleted( |
- const WebsiteSettingsUI::ChosenObjectInfo& info) override; |
+ void OnChosenObjectDeleted(const PageInfoUI::ChosenObjectInfo& info) override; |
// views::BubbleDialogDelegateView implementation. |
base::string16 GetWindowTitle() const override; |
@@ -128,7 +127,7 @@ class WebsiteSettingsPopupView : public content::WebContentsObserver, |
// views::View implementation. |
gfx::Size GetPreferredSize() const override; |
- // WebsiteSettingsUI implementations. |
+ // PageInfoUI implementations. |
void SetCookieInfo(const CookieInfoList& cookie_info_list) override; |
void SetPermissionInfo(const PermissionInfoList& permission_info_list, |
ChosenObjectInfoList chosen_object_info_list) override; |
@@ -146,8 +145,8 @@ class WebsiteSettingsPopupView : public content::WebContentsObserver, |
// Whether DevTools is disabled for the relevant profile. |
bool is_devtools_disabled_; |
- // The presenter that controls the Website Settings UI. |
- std::unique_ptr<WebsiteSettings> presenter_; |
+ // The presenter that controls the Page Info UI. |
+ std::unique_ptr<PageInfo> presenter_; |
Profile* profile_; |
@@ -178,9 +177,9 @@ class WebsiteSettingsPopupView : public content::WebContentsObserver, |
// |Permission| changes. |
std::vector<std::unique_ptr<PermissionSelectorRow>> selector_rows_; |
- base::WeakPtrFactory<WebsiteSettingsPopupView> weak_factory_; |
+ base::WeakPtrFactory<PageInfoPopupView> weak_factory_; |
- DISALLOW_COPY_AND_ASSIGN(WebsiteSettingsPopupView); |
+ DISALLOW_COPY_AND_ASSIGN(PageInfoPopupView); |
}; |
-#endif // CHROME_BROWSER_UI_VIEWS_PAGE_INFO_WEBSITE_SETTINGS_POPUP_VIEW_H_ |
+#endif // CHROME_BROWSER_UI_VIEWS_PAGE_INFO_PAGE_INFO_POPUP_VIEW_H_ |